Module xrt

Module xrt 

Modules

device_assignment
Nested message and enum types in DeviceAssignment.
xrt_chained_execute_op
Nested message and enum types in XRTChainedExecuteOp.

Structs

DeviceAssignment
XlaAllocation
Literal to allocate space for, and transfer to, device memory.
XlaComputation
Options and XLA computation for a compilation.
XlaComputationConfig
Options for an XLA compilation.
XlaTupleNode
Node in a tree describing a tuple constructed from input handles. A node is an internal node if tuples is non-empty, in which case input_index and release_input_handle are ignored. Otherwise a node is a leaf node. Each leaf XLATupleNode is the index of an input which corresponds to a handle that will be grafted onto the output tuple at that location. If release_input_handle is true that input handle will be released and become invalid. Inputs may be repeated in which case leaves of the output tuple will alias. If an input is repeated, release_input_handle must be false for every leaf where that input appears.
XrtChainedExecuteConfig
XrtChainedExecuteOp
A single chained execute operation. An operation can either be a device data load, or an existing (as in, previously compiled and accessible via its int64 handle) XLA computation execution.
XrtChainedExecutePlan
Execution plan for the XRTChainedExecute operation.
XrtExecutionConfig
Options for an XLA execution.